==> flink-1.18.1-src.tgz: flink-1.18.1/flink-runtime/src/test/java/org/apache/flink/runtime/rest/messages/job/savepoints/SavepointDisposalRequestTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.runtime.rest.messages.job.savepoints;

import org.apache.flink.runtime.rest.messages.RestRequestMarshallingTestBase;

import org.hamcrest.Matchers;
import org.junit.Assert;

import java.util.UUID;

/** Tests the un/marshalling of the {@link SavepointDisposalRequest}. */
public class SavepointDisposalRequestTest
        extends RestRequestMarshallingTestBase<SavepointDisposalRequest> {

    @Override
    protected Class<SavepointDisposalRequest> getTestRequestClass() {
        return SavepointDisposalRequest.class;
    }

    @Override
    protected SavepointDisposalRequest getTestRequestInstance() {
        return new SavepointDisposalRequest(UUID.randomUUID().toString());
    }

    @Override
    protected void assertOriginalEqualsToUnmarshalled(
            SavepointDisposalRequest expected, SavepointDisposalRequest actual) {
        Assert.assertThat(
                actual.getSavepointPath(),
                Matchers.is(Matchers.equalTo(expected.getSavepointPath())));
    }
}

==> flink-1.19.3-src.tgz: flink-1.19.3/flink-runtime/src/test/java/org/apache/flink/runtime/rest/messages/job/savepoints/SavepointDisposalRequestTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.runtime.rest.messages.job.savepoints;

import org.apache.flink.runtime.rest.messages.RestRequestMarshallingTestBase;
import org.apache.flink.testutils.junit.extensions.parameterized.NoOpTestExtension;

import org.junit.jupiter.api.extension.ExtendWith;

import java.util.UUID;

import static org.assertj.core.api.Assertions.assertThat;

/** Tests the un/marshalling of the {@link SavepointDisposalRequest}. */
@ExtendWith(NoOpTestExtension.class)
class SavepointDisposalRequestTest
        extends RestRequestMarshallingTestBase<SavepointDisposalRequest> {

    @Override
    protected Class<SavepointDisposalRequest> getTestRequestClass() {
        return SavepointDisposalRequest.class;
    }

    @Override
    protected SavepointDisposalRequest getTestRequestInstance() {
        return new SavepointDisposalRequest(UUID.randomUUID().toString());
    }

    @Override
    protected void assertOriginalEqualsToUnmarshalled(
            SavepointDisposalRequest expected, SavepointDisposalRequest actual) {
        assertThat(actual.getSavepointPath()).isEqualTo(expected.getSavepointPath());
    }
}
